  <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    <xsl:template match="Dictionary">
    <html>
      <head>
        <title><xsl:value-of select="Label"/></title>
        <style>
          .vset {
          width: 100%;
          }
          .vsetitem {
          border-bottom-style:solid;
          border-bottom-color: #e0e0e0;
          border-bottom-width=1px;
          border-left-style: none;
          border-right-style: none;
          border-top-style: none;
          }
          .item {
          border-style: solid;
          border-width=1px;
          padding=5px;
          page-break-inside: avoid;
          }
          .itemlabel {
          color: blue;
          }
          .questiontext {
          width: 100%;
          background-color:#d0d0d0;
          }

          .occlabels table {
          border-collapse: collapse;
          margin: 1.5em;
          }
          .occlabels th, td {
          padding: 3px;
          }
          .occlabels th {
          background-color:#d0d0d0;
          }
          .occlabels td {
          background-color:white;
          }
          .occlabels table, th, td {
          border: 1px solid black;
          }
        </style>
      </head>
      <body>
        <H1>Dictionary: <xsl:value-of select="Label"/></H1>
        <xsl:apply-templates select="Level"/>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="Level">
    <H2>Level: <xsl:value-of select="Label"/></H2>
    <xsl:apply-templates select="IdItems"/>
    <xsl:apply-templates select="Record"/>
  </xsl:template>
  <xsl:template match="IdItems">
      <H3>Id Items:</H3>
    <xsl:apply-templates select="Item"/>
    </xsl:template>
  <xsl:template match="Record">
    <H3>Record: <xsl:value-of select="Label"/></H3>
    <div><xsl:apply-templates select="OccurenceLabels"/></div>
    <xsl:apply-templates select="Item"/>
  </xsl:template>
  <xsl:template match="Item">
    <div class="item">
      <div class="itemlabel">
        <xsl:value-of select="Label"/>
      </div>
      <div class="questiontext"><xsl:apply-templates select="Question"/></div>
      <div><xsl:apply-templates select="ValueSet"/></div>
      <div><xsl:apply-templates select="OccurenceLabels"/></div>
    </div>
    <br/>
  </xsl:template>
    <xsl:template match="QuestionText|QuestionHelp">
      <xsl:if test="@Format='xhtml'">
        <xsl:value-of disable-output-escaping="yes" select="."/>
      </xsl:if>
    </xsl:template>
    <xsl:template match="ValueSet">
      <table class = "vset">
      <xsl:apply-templates select="Value"/>
      </table>
    </xsl:template>
    <xsl:template match="Value">
      <tr>
        <td class="vsetitem">
          <div style="float: left;">
            <xsl:value-of select="Label"/>
          </div>
          <div style="float: right;">
            <xsl:value-of select="Range/@From"/>
            <xsl:if test="Range/@To">
              <xsl:text> - </xsl:text>
              <xsl:value-of select="Range/@To"/>
            </xsl:if>
          </div>
        </td>
      </tr>
    </xsl:template>
    <xsl:template match="OccurenceLabels">
      <div class = "occlabels">
        <table>
          <tr>
            <th>Occurrence</th>
            <th>Label</th>
          </tr>
          <xsl:apply-templates select="OccurrenceLabel"/>
        </table>
      </div>
    </xsl:template>
    <xsl:template match="OccurenceLabels[not(OccurrenceLabel)]">
    </xsl:template>
    <xsl:template match="OccurrenceLabel">
      <tr>
        <td>
          <xsl:value-of select="@Occurrence"/>
        </td>
        <td>
            <xsl:value-of select="Label"/>
        </td>
      </tr>
    </xsl:template>
  </xsl:stylesheet>
